@@ -61,8 +61,9 @@ class PointsScoredYearCalculator(YearCalculator):
         """
 
         teamIdAndPointsScored = cls.getPointsScored(year, **kwargs)
-        teamIdAndNumberOfGamesPlayed = YearNavigator.getNumberOfGamesPlayed(year, YearFilters.getForYear(year,
-                                                                                                         **kwargs))
+        teamIdAndNumberOfGamesPlayed = YearNavigator.getNumberOfGamesPlayed(
+            year, YearFilters.getForYear(year, **kwargs)
+        )
 
         teamIdAndPointsScoredPerGame = dict()
         allTeamIds = YearNavigator.getAllTeamIds(year)
@@ -71,8 +72,9 @@ class PointsScoredYearCalculator(YearCalculator):
             if teamIdAndNumberOfGamesPlayed[teamId] == 0:
                 teamIdAndPointsScoredPerGame[teamId] = None
             else:
-                teamIdAndPointsScoredPerGame[teamId] = teamIdAndPointsScored[teamId] / teamIdAndNumberOfGamesPlayed[
-                    teamId]
+                teamIdAndPointsScoredPerGame[teamId] = (
+                    teamIdAndPointsScored[teamId] / teamIdAndNumberOfGamesPlayed[teamId]
+                )
 
         return teamIdAndPointsScoredPerGame
 
@@ -101,15 +103,23 @@ class PointsScoredYearCalculator(YearCalculator):
             week = year.weeks[i]
             for matchup in week.matchups:
                 if matchup.matchupType in filters.includeMatchupTypes:
-                    teamIdAndOpponentPointsScored[matchup.teamAId] += Deci(matchup.teamBScore)
-                    teamIdAndOpponentPointsScored[matchup.teamBId] += Deci(matchup.teamAScore)
+                    teamIdAndOpponentPointsScored[matchup.teamAId] += Deci(
+                        matchup.teamBScore
+                    )
+                    teamIdAndOpponentPointsScored[matchup.teamBId] += Deci(
+                        matchup.teamAScore
+                    )
 
-        cls._setToNoneIfNoGamesPlayed(teamIdAndOpponentPointsScored, year, filters, **kwargs)
+        cls._setToNoneIfNoGamesPlayed(
+            teamIdAndOpponentPointsScored, year, filters, **kwargs
+        )
         return teamIdAndOpponentPointsScored
 
     @classmethod
     @validateYear
-    def getOpponentPointsScoredPerGame(cls, year: Year, **kwargs) -> dict[str, Optional[Deci]]:
+    def getOpponentPointsScoredPerGame(
+        cls, year: Year, **kwargs
+    ) -> dict[str, Optional[Deci]]:
         """
         Returns the number of opponent Points Scored per game for each team in the given Year.
         Returns None for a Team if they have no games played in the range.
@@ -124,8 +134,9 @@ class PointsScoredYearCalculator(YearCalculator):
         """
 
         teamIdAndOpponentPointsScored = cls.getOpponentPointsScored(year, **kwargs)
-        teamIdAndNumberOfGamesPlayed = YearNavigator.getNumberOfGamesPlayed(year, YearFilters.getForYear(year,
-                                                                                                         **kwargs))
+        teamIdAndNumberOfGamesPlayed = YearNavigator.getNumberOfGamesPlayed(
+            year, YearFilters.getForYear(year, **kwargs)
+        )
 
         teamIdAndOpponentPointsScoredPerGame = dict()
         allTeamIds = YearNavigator.getAllTeamIds(year)
@@ -134,7 +145,9 @@ class PointsScoredYearCalculator(YearCalculator):
             if teamIdAndNumberOfGamesPlayed[teamId] == 0:
                 teamIdAndOpponentPointsScoredPerGame[teamId] = None
             else:
-                teamIdAndOpponentPointsScoredPerGame[teamId] = teamIdAndOpponentPointsScored[teamId] / \
-                                                               teamIdAndNumberOfGamesPlayed[teamId]
+                teamIdAndOpponentPointsScoredPerGame[teamId] = (
+                    teamIdAndOpponentPointsScored[teamId]
+                    / teamIdAndNumberOfGamesPlayed[teamId]
+                )
 
         return teamIdAndOpponentPointsScoredPerGame
