@@ -2,9 +2,11 @@ from .AWALYearCalculator import AWALYearCalculator
 from .GameOutcomeYearCalculator import GameOutcomeYearCalculator
 from .PlusMinusYearCalculator import PlusMinusYearCalculator
 from .PointsScoredYearCalculator import PointsScoredYearCalculator
-from .SSLYearCalculator import SSLYearCalculator
 from .ScoringShareYearCalculator import ScoringShareYearCalculator
-from .ScoringStandardDeviationYearCalculator import ScoringStandardDeviationYearCalculator
+from .ScoringStandardDeviationYearCalculator import (
+    ScoringStandardDeviationYearCalculator,
+)
 from .SingleScoreYearCalculator import SingleScoreYearCalculator
 from .SmartWinsYearCalculator import SmartWinsYearCalculator
+from .SSLYearCalculator import SSLYearCalculator
 from .TeamSummaryYearCalculator import TeamSummaryYearCalculator
