@@ -1,9 +1,12 @@
+from typing import Optional
+
 import espn_api.football as espn
 from espn_api.football import League as ESPNLeague
 from espn_api.football import Team as ESPNTeam
 
 from leeger.enum.MatchupType import MatchupType
 from leeger.league_loader.LeagueLoader import LeagueLoader
+from leeger.model.league.Division import Division
 from leeger.model.league.League import League
 from leeger.model.league.Matchup import Matchup
 from leeger.model.league.Owner import Owner
@@ -32,18 +35,33 @@ class ESPNLeagueLoader(LeagueLoader):
     }
 
     def __init__(
-        self, leagueId: str, years: list[int], espnS2: str = None, swid: str = None, **kwargs
+        self,
+        leagueId: str,
+        years: list[int],
+        *,
+        espnS2: str = None,
+        swid: str = None,
+        ownerNamesAndAliases: Optional[dict[str, list[str]]] = None,
+        leagueName: Optional[str] = None,
     ):
         # validation
         try:
             int(leagueId)
         except ValueError:
             raise ValueError(f"League ID '{leagueId}' could not be turned into an int.")
-        super().__init__(leagueId, years, **kwargs)
+        super().__init__(
+            leagueId,
+            years,
+            ownerNamesAndAliases=ownerNamesAndAliases,
+            leagueName=leagueName,
+        )
 
         self.__espnS2 = espnS2
         self.__swid = swid
         self.__espnTeamIdToTeamMap: dict[str, Team] = dict()
+        self.__espnDivisionIdToDivisionMap: dict[int, Division] = (
+            dict()
+        )  # holds the division info for ONLY the current year
 
     def __getAllLeagues(self) -> list[ESPNLeague]:
         espnLeagueYears = list()
@@ -56,6 +74,7 @@ class ESPNLeagueLoader(LeagueLoader):
                     swid=self.__swid,
                 )
             )
+        self._validateRetrievedLeagues(espnLeagueYears)
         return espnLeagueYears
 
     def getOwnerNames(self) -> dict[int, list[str]]:
@@ -73,30 +92,58 @@ class ESPNLeagueLoader(LeagueLoader):
         if validate:
             # validate new league
             leagueValidation.runAllChecks(league)
+        self._warnForUnusedOwnerNames(league)
         return league
 
     def __buildLeague(self, espnLeagues: list[ESPNLeague]) -> League:
         years = list()
         for espnLeague in espnLeagues:
+            # save league name for each year
+            self._leagueNameByYear[espnLeague.year] = espnLeague.settings.name
             self.__loadOwners(espnLeague.teams)
             years.append(self.__buildYear(espnLeague))
-        # use the league name from the most recent year
-        return League(name=espnLeagues[-1].settings.name, owners=self._owners, years=years)
+        return League(
+            name=self._getLeagueName(),
+            owners=self._owners,
+            years=self._getValidYears(years),
+        )
 
     def __loadOwners(self, espnTeams: list[ESPNTeam]) -> None:
         if self._owners is None:
             owners = list()
             for espnTeam in espnTeams:
                 # get general owner name if there is one
-                generalOwnerName = self._getGeneralOwnerNameFromGivenOwnerName(espnTeam.owner)
-                ownerName = generalOwnerName if generalOwnerName is not None else espnTeam.owner
+                ownerName = self.__getESPNOwnerName(espnTeam.owners)
+                generalOwnerName = self._getGeneralOwnerNameFromGivenOwnerName(
+                    ownerName
+                )
+                ownerName = (
+                    generalOwnerName if generalOwnerName is not None else ownerName
+                )
                 owners.append(Owner(name=ownerName))
             self._owners = owners
 
     def __buildYear(self, espnLeague: ESPNLeague) -> Year:
+        # save division info
+        for (
+            espnDivisionId,
+            espnDivisionName,
+        ) in espnLeague.settings.division_map.items():
+            self.__espnDivisionIdToDivisionMap[espnDivisionId] = Division(
+                name=espnDivisionName
+            )
         teams = self.__buildTeams(espnLeague.teams)
         weeks = self.__buildWeeks(espnLeague)
-        return Year(yearNumber=espnLeague.year, teams=teams, weeks=weeks)
+        # TODO: see if there are cases where ESPN leagues do NOT have divisions
+        year = Year(
+            yearNumber=espnLeague.year,
+            teams=teams,
+            weeks=weeks,
+            divisions=list(self.__espnDivisionIdToDivisionMap.values()),
+        )
+        # clear division info
+        self.__espnDivisionIdToDivisionMap = dict()
+        return year
 
     def __buildWeeks(self, espnLeague: ESPNLeague) -> list[Week]:
         weeks = list()
@@ -127,12 +174,16 @@ class ESPNLeagueLoader(LeagueLoader):
                 ).scores[i]
                 # figure out tiebreakers if there needs to be one
                 teamAHasTiebreaker = (
-                    teamAScore == teamBScore and espnTeamA.outcomes[i] == self.__ESPN_WIN_OUTCOME
+                    teamAScore == teamBScore
+                    and espnTeamA.outcomes[i] == self.__ESPN_WIN_OUTCOME
                 )
                 teamBHasTiebreaker = (
-                    teamAScore == teamBScore and espnTeamB.outcomes[i] == self.__ESPN_WIN_OUTCOME
+                    teamAScore == teamBScore
+                    and espnTeamB.outcomes[i] == self.__ESPN_WIN_OUTCOME
+                )
+                matchupType = self.__getMatchupType(
+                    espnLeague, i + 1, espnTeamA.team_id
                 )
-                matchupType = self.__getMatchupType(espnLeague, i + 1, espnTeamA.team_id)
                 matchups.append(
                     Matchup(
                         teamAId=teamA.id,
@@ -161,11 +212,14 @@ class ESPNLeagueLoader(LeagueLoader):
             if playoffTeamCount >= espnTeam.standing:
                 # this team made the playoffs
                 # figure out if this is the last week of playoffs (the championship week)
-                numberOfPlayoffWeeks = self.__TEAMS_IN_PLAYOFFS_TO_PLAYOFF_WEEK_COUNT_MAP[
-                    playoffTeamCount
-                ]
+                numberOfPlayoffWeeks = (
+                    self.__TEAMS_IN_PLAYOFFS_TO_PLAYOFF_WEEK_COUNT_MAP[playoffTeamCount]
+                )
                 # TODO: Raise specific exception here if not found in map
-                if weekNumber == espnLeague.settings.reg_season_count + numberOfPlayoffWeeks:
+                if (
+                    weekNumber
+                    == espnLeague.settings.reg_season_count + numberOfPlayoffWeeks
+                ):
                     # this is the championship week
                     # figure out if this team has lost in the playoffs before this week
                     playoffOutcomes = espnTeam.outcomes[-numberOfPlayoffWeeks:-1]
@@ -193,8 +247,28 @@ class ESPNLeagueLoader(LeagueLoader):
     def __buildTeams(self, espnTeams: list[ESPNTeam]) -> list[Team]:
         teams = list()
         for espnTeam in espnTeams:
-            owner = self._getOwnerByName(espnTeam.owner)
-            team = Team(ownerId=owner.id, name=espnTeam.team_name)
+            # TODO: see if there are cases where ESPN leagues do NOT have divisions
+            divisionId = self.__espnDivisionIdToDivisionMap[espnTeam.division_id].id
+            ownerName = self.__getESPNOwnerName(espnTeam.owners)
+            owner = self._getOwnerByName(ownerName)
+            team = Team(
+                ownerId=owner.id, name=espnTeam.team_name, divisionId=divisionId
+            )
             teams.append(team)
             self.__espnTeamIdToTeamMap[espnTeam.team_id] = team
         return teams
+
+    def __getESPNOwnerName(self, espnOwners: list[dict]) -> str:
+        """
+        Owners look like this:
+        [
+            {
+                "displayName": "FooBarBazQuz",
+                "firstName": "Foo",
+                "id": "{1B3463F3-B3C6-4053-9893-EdB9C7805888}",
+                "lastName": "Bar",
+                ...
+            }
+        ]
+        """
+        return f"{espnOwners[0]['firstName']} {espnOwners[0]['lastName']}"
