@@ -2,9 +2,17 @@ from functools import lru_cache
 
 from leeger.exception.InvalidYearFormatException import InvalidYearFormatException
 from leeger.model.league import Matchup, YearSettings
+from leeger.model.league.Division import Division
+from leeger.model.league.Team import Team
+from leeger.model.league.Week import Week
 from leeger.model.league.Year import Year
 from leeger.util.navigator import YearNavigator
-from leeger.validate import teamValidation, weekValidation, yearSettingsValidation
+from leeger.validate import (
+    divisionValidation,
+    teamValidation,
+    weekValidation,
+    yearSettingsValidation,
+)
 
 
 @lru_cache(maxsize=None)
@@ -17,14 +25,17 @@ def runAllChecks(year: Year) -> None:
     checkYearSettings(year)
     checkAllWeeks(year)
     checkAllTeams(year)
+    checkAllDivisions(year)
     checkForDuplicateTeams(year)
     checkForDuplicateWeeks(year)
+    checkForDuplicateDivisions(year)
     checkAtLeastOneWeekInYear(year)
     checkWeekNumberingInYear(year)
     checkPlayoffWeekOrderingInYear(year)
     checkAtLeastTwoTeamsInYear(year)
     checkGivenYearHasValidYearNumber(year)
     checkTeamNamesInYear(year)
+    checkDivisionNamesInYear(year)
     checkTeamOwnerIdsInYear(year)
     checkEveryTeamInYearIsInAMatchup(year)
     checkMultiWeekMatchupsAreInConsecutiveWeeks(year)
@@ -32,6 +43,9 @@ def runAllChecks(year: Year) -> None:
     checkMultiWeekMatchupsWithSameIdHaveSameMatchupType(year)
     checkMultiWeekMatchupsWithSameIdHaveSameTeamIds(year)
     checkMultiWeekMatchupsWithSameIdHaveSameTiebreakers(year)
+    checkEitherAllTeamsAreInADivisionOrNoTeamsAreInADivision(year)
+    checkDivisionIdsMatchTeamDivisionIds(year)
+    checkDivisionsHaveNoDuplicateIds(year)
 
 
 def checkYearSettings(year: Year) -> None:
@@ -57,6 +71,14 @@ def checkAllTeams(year: Year) -> None:
         teamValidation.runAllChecks(team)
 
 
+def checkAllDivisions(year: Year) -> None:
+    """
+    Runs all checks on all Divisions.
+    """
+    for division in year.divisions:
+        divisionValidation.runAllChecks(division)
+
+
 def checkAllTypes(year: Year) -> None:
     """
     Runs all checks on the given Year.
@@ -64,10 +86,18 @@ def checkAllTypes(year: Year) -> None:
 
     if not isinstance(year.yearNumber, int):
         raise InvalidYearFormatException("yearNumber must be type 'int'.")
-    if not isinstance(year.teams, list):
-        raise InvalidYearFormatException("teams must be type 'list'.")
-    if not isinstance(year.weeks, list):
-        raise InvalidYearFormatException("weeks must be type 'list'.")
+    if not isinstance(year.teams, list) or not all(
+        isinstance(team, Team) for team in year.teams
+    ):
+        raise InvalidYearFormatException("teams must be type 'list[Team]'.")
+    if not isinstance(year.weeks, list) or not all(
+        isinstance(week, Week) for week in year.weeks
+    ):
+        raise InvalidYearFormatException("weeks must be type 'list[Week]'.")
+    if not isinstance(year.divisions, list) or not all(
+        isinstance(division, Division) for division in year.divisions
+    ):
+        raise InvalidYearFormatException("divisions must be type 'list[Division]'.")
     if not isinstance(year.yearSettings, YearSettings):
         raise InvalidYearFormatException("yearSettings must be type 'YearSettings'.")
 
@@ -96,12 +126,47 @@ def checkForDuplicateWeeks(year: Year) -> None:
             weekInstanceIds.append(id(week))
 
 
+def checkForDuplicateDivisions(year: Year) -> None:
+    """
+    Checks that all Weeks are unique instances.
+    """
+    divisionInstanceIds = list()
+    for division in year.divisions:
+        if id(division) in divisionInstanceIds:
+            raise InvalidYearFormatException("Divisions must all be unique instances.")
+        else:
+            divisionInstanceIds.append(id(division))
+
+
+def checkDivisionNamesInYear(year: Year) -> None:
+    """
+    Checks that each division in the given Year has a unique name
+    Counts names as too similar if they are the same
+        - when whitespace is removed
+        - when case is uniform
+    """
+    if len(set([division.name for division in year.divisions])) != len(
+        [division.name for division in year.divisions]
+    ):
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} has divisions with duplicate names."
+        )
+    if len(set([division.name.strip().upper() for division in year.divisions])) != len(
+        [division.name for division in year.divisions]
+    ):
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} has divisions with very similar names."
+        )
+
+
 def checkAtLeastOneWeekInYear(year: Year) -> None:
     """
     Checks that there is a minimum of 1 week in the given Year.
     """
     if len(year.weeks) == 0:
-        raise InvalidYearFormatException(f"Year {year.yearNumber} does not have at least 1 week.")
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} does not have at least 1 week."
+        )
 
 
 def checkWeekNumberingInYear(year: Year) -> None:
@@ -116,7 +181,9 @@ def checkWeekNumberingInYear(year: Year) -> None:
         weekNumbers.append(week.weekNumber)
 
     if len(set(weekNumbers)) != len(weekNumbers):
-        raise InvalidYearFormatException(f"Year {year.yearNumber} has duplicate week numbers.")
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} has duplicate week numbers."
+        )
 
     if weekNumbers[0] != 1:
         raise InvalidYearFormatException(
@@ -160,7 +227,9 @@ def checkAtLeastTwoTeamsInYear(year: Year) -> None:
     Checks that there is at least 2 teams in the given Year.
     """
     if len(year.teams) < 2:
-        raise InvalidYearFormatException(f"Year {year.yearNumber} needs at least 2 teams.")
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} needs at least 2 teams."
+        )
 
 
 def checkGivenYearHasValidYearNumber(year: Year) -> None:
@@ -169,7 +238,9 @@ def checkGivenYearHasValidYearNumber(year: Year) -> None:
     1920 is the year the NFL was founded, so we'll assume nobody was playing fantasy football before then.
     """
     if year.yearNumber < 1920 or year.yearNumber > 2999:
-        raise InvalidYearFormatException(f"Year {year.yearNumber} is not in range 1920-2XXX.")
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} is not in range 1920-2XXX."
+        )
 
 
 def checkTeamNamesInYear(year: Year) -> None:
@@ -179,8 +250,12 @@ def checkTeamNamesInYear(year: Year) -> None:
         - when whitespace is removed
         - when case is uniform
     """
-    if len(set([team.name for team in year.teams])) != len([team.name for team in year.teams]):
-        raise InvalidYearFormatException(f"Year {year.yearNumber} has teams with duplicate names.")
+    if len(set([team.name for team in year.teams])) != len(
+        [team.name for team in year.teams]
+    ):
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} has teams with duplicate names."
+        )
     if len(set([team.name.strip().upper() for team in year.teams])) != len(
         [team.name for team in year.teams]
     ):
@@ -243,7 +318,9 @@ def checkMultiWeekMatchupsAreInConsecutiveWeeks(year: Year):
 
         # skip first week since we can't end or invalidate any multi-week matchups after just 1 week
         if i != 0:
-            previousWeekMWMIDs = weekNumberToMultiWeekMatchupIdListMap[week.weekNumber - 1]
+            previousWeekMWMIDs = weekNumberToMultiWeekMatchupIdListMap[
+                week.weekNumber - 1
+            ]
             currentWeekMWMIDs = weekNumberToMultiWeekMatchupIdListMap[week.weekNumber]
 
             for mwmid in previousWeekMWMIDs:
@@ -284,7 +361,10 @@ def checkMultiWeekMatchupsAreInMoreThanOneWeekOrAreNotTheMostRecentWeek(year: Ye
                         isMostRecentWeekInYear,
                     ]
 
-    for (mwmid, countAndMostRecentWeek) in multiWeekMatchupIdToCountAndMostRecentWeekMap.items():
+    for (
+        mwmid,
+        countAndMostRecentWeek,
+    ) in multiWeekMatchupIdToCountAndMostRecentWeekMap.items():
         count, isMostRecentWeek = countAndMostRecentWeek
         if count == 1 and not isMostRecentWeek:
             raise InvalidYearFormatException(
@@ -296,14 +376,15 @@ def checkMultiWeekMatchupsWithSameIdHaveSameMatchupType(year: Year):
     """
     Checks that all multi-week matchups with the same ID have the same MatchupType.
     """
-    multiWeekMatchupIdToMatchupListMap: dict[
-        str, list[Matchup]
-    ] = YearNavigator.getAllMultiWeekMatchups(year)
+    multiWeekMatchupIdToMatchupListMap: dict[str, list[Matchup]] = (
+        YearNavigator.getAllMultiWeekMatchups(year)
+    )
 
     for mwmid, matchupList in multiWeekMatchupIdToMatchupListMap.items():
         if len(matchupList) > 0:
             if not all(
-                matchup.matchupType == matchupList[0].matchupType for matchup in matchupList
+                matchup.matchupType == matchupList[0].matchupType
+                for matchup in matchupList
             ):
                 raise InvalidYearFormatException(
                     f"Multi-week matchups with ID '{mwmid}' do not all have the same matchup type."
@@ -314,9 +395,9 @@ def checkMultiWeekMatchupsWithSameIdHaveSameTeamIds(year: Year):
     """
     Checks that all multi-week matchups with the same ID have the same team A and team B
     """
-    multiWeekMatchupIdToMatchupListMap: dict[
-        str, list[Matchup]
-    ] = YearNavigator.getAllMultiWeekMatchups(year)
+    multiWeekMatchupIdToMatchupListMap: dict[str, list[Matchup]] = (
+        YearNavigator.getAllMultiWeekMatchups(year)
+    )
 
     for mwmid, matchupList in multiWeekMatchupIdToMatchupListMap.items():
         if len(matchupList) > 0:
@@ -334,9 +415,9 @@ def checkMultiWeekMatchupsWithSameIdHaveSameTiebreakers(year: Year):
     """
     Checks that all multi-week matchups with the same ID have the same tiebreakers
     """
-    multiWeekMatchupIdToMatchupListMap: dict[
-        str, list[Matchup]
-    ] = YearNavigator.getAllMultiWeekMatchups(year)
+    multiWeekMatchupIdToMatchupListMap: dict[str, list[Matchup]] = (
+        YearNavigator.getAllMultiWeekMatchups(year)
+    )
 
     for mwmid, matchupList in multiWeekMatchupIdToMatchupListMap.items():
         if len(matchupList) > 0:
@@ -348,3 +429,67 @@ def checkMultiWeekMatchupsWithSameIdHaveSameTiebreakers(year: Year):
                 raise InvalidYearFormatException(
                     f"Multi-week matchups with ID '{mwmid}' do not all have the same tiebreakers."
                 )
+
+
+def checkEitherAllTeamsAreInADivisionOrNoTeamsAreInADivision(year: Year):
+    """
+    Checks that either all teams are in a division or no teams are in a division.
+    """
+    allTeamDivisionIds = [team.divisionId for team in year.teams]
+
+    if not (
+        all(isinstance(divisionId, str) for divisionId in allTeamDivisionIds)
+        or all(divisionId is None for divisionId in allTeamDivisionIds)
+    ):
+        raise InvalidYearFormatException(
+            f"Only some teams in Year {year.yearNumber} have a Division ID."
+        )
+
+
+def checkDivisionIdsMatchTeamDivisionIds(year: Year):
+    """
+    Checks that the divisions in a year exactly match all division IDs for all teams in a year.
+    """
+    allUniqueDivisionIds = {division.id for division in year.divisions}
+    allUniqueTeamDivisionIds = {
+        team.divisionId for team in year.teams if team.divisionId is not None
+    }
+
+    if allUniqueDivisionIds != allUniqueTeamDivisionIds:
+        if len(allUniqueDivisionIds) == 0:
+            # no divisions, some team division ids
+            raise InvalidYearFormatException(
+                f"Teams in Year {year.yearNumber} have Division IDs, but Year {year.yearNumber} has no Divisions."
+            )
+        elif len(allUniqueTeamDivisionIds) == 0:
+            # some divisions, no team division ids
+            raise InvalidYearFormatException(
+                f"Year {year.yearNumber} has Divisions, but Teams in Year {year.yearNumber} have Division IDs."
+            )
+        elif len(allUniqueDivisionIds) > len(allUniqueTeamDivisionIds):
+            # some divisions, some team division ids, more divisions than division team ids
+            raise InvalidYearFormatException(
+                f"There are Divisions in Year {year.yearNumber} that do not belong to any Team."
+            )
+        elif len(allUniqueDivisionIds) < len(allUniqueTeamDivisionIds):
+            # some divisions, some team division ids, more division team ids than divisions
+            raise InvalidYearFormatException(
+                f"There are Teams with Division IDs in Year {year.yearNumber} that do not belong to any Division."
+            )
+        else:
+            # same number of divisions and team division ids, they do not match
+            raise InvalidYearFormatException(
+                f"The Divisions in Year {year.yearNumber} do not corrospond correctly to the Team Division IDs in Year {year.yearNumber}."
+            )
+
+
+def checkDivisionsHaveNoDuplicateIds(year: Year):
+    """
+    Checks that all divisions have a unique ID.
+    """
+    allDivisionIds = [division.id for division in year.divisions]
+
+    if len(set(allDivisionIds)) != len(allDivisionIds):
+        raise InvalidYearFormatException(
+            f"Year {year.yearNumber} has duplicate division IDs."
+        )
