@@ -32,6 +32,19 @@ class TestPerformance(unittest.TestCase):
         self.assertFalse(performance.hasTiebreaker)
         self.assertIsNone(performance.multiWeekMatchupId)
 
+    def test_performance_eq_callsEqualsMethod(self):
+        # create Performance 1
+        _, teams_1 = getNDefaultOwnersAndTeams(2)
+        performance_1 = Performance(
+            teamId=teams_1[0].id,
+            teamScore=1.1,
+            hasTiebreaker=True,
+            multiWeekMatchupId="1",
+            matchupType=MatchupType.REGULAR_SEASON,
+        )
+
+        self.assertTrue(performance_1 == performance_1)
+
     def test_performance_eq_equal(self):
         # create Performance 1
         _, teams_1 = getNDefaultOwnersAndTeams(2)
@@ -44,16 +57,15 @@ class TestPerformance(unittest.TestCase):
         )
 
         # create Matchup 2
-        _, teams_2 = getNDefaultOwnersAndTeams(2)
         performance_2 = Performance(
-            teamId=teams_2[0].id,
+            teamId=teams_1[0].id,
             teamScore=1.1,
             hasTiebreaker=True,
             multiWeekMatchupId="1",
             matchupType=MatchupType.REGULAR_SEASON,
         )
 
-        self.assertEqual(performance_1, performance_2)
+        self.assertTrue(performance_1.equals(performance_2, ignoreBaseIds=True))
 
     def test_performance_eq_notEqual(self):
         # create Performance 1
@@ -76,7 +88,7 @@ class TestPerformance(unittest.TestCase):
             matchupType=MatchupType.REGULAR_SEASON,
         )
 
-        self.assertNotEqual(performance_1, performance_2)
+        self.assertFalse(performance_1.equals(performance_2, ignoreBaseIds=True))
 
     def test_performance_toJson(self):
         performance = Performance(
@@ -123,7 +135,9 @@ class TestPerformance(unittest.TestCase):
         self.assertFalse(response.teamBHasTiebreaker)
         self.assertEqual("id", response.multiWeekMatchupId)
 
-    def test_performance_add_performancesHaveDifferentMatchupTypes_raisesException(self):
+    def test_performance_add_performancesHaveDifferentMatchupTypes_raisesException(
+        self,
+    ):
         performance_1 = Performance(
             teamId="team1Id",
             teamScore=1.1,
@@ -147,7 +161,9 @@ class TestPerformance(unittest.TestCase):
             str(context.exception),
         )
 
-    def test_performance_add_performancesHaveDifferentMultiWeekMatchupIds_raisesException(self):
+    def test_performance_add_performancesHaveDifferentMultiWeekMatchupIds_raisesException(
+        self,
+    ):
         performance_1 = Performance(
             teamId="team1Id",
             teamScore=1.1,
