@@ -6,6 +6,7 @@ from decimal import Decimal
 from openpyxl import load_workbook
 from openpyxl.utils import get_column_letter
 
+from leeger.model.league.Division import Division
 from leeger.model.league.League import League
 from leeger.model.league.Matchup import Matchup
 from leeger.model.league.Team import Team
@@ -17,20 +18,41 @@ from test.helper.prototypes import getNDefaultOwnersAndTeams
 
 class TestExcel(unittest.TestCase):
     def test_leagueToExcel_filePathGiven_happyPath(self):
+        division1 = Division(name="d1")
+        division2 = Division(name="d2")
         owners, teams1 = getNDefaultOwnersAndTeams(2)
         teams1[0].name = "a"
         teams1[1].name = "b"
-        matchup1 = Matchup(teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2)
+        teams1[0].divisionId = division1.id
+        teams1[1].divisionId = division2.id
+        matchup1 = Matchup(
+            teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2
+        )
         week1 = Week(weekNumber=1, matchups=[matchup1])
-        year1 = Year(yearNumber=2000, teams=teams1, weeks=[week1])
+        year1 = Year(
+            yearNumber=2000,
+            teams=teams1,
+            weeks=[week1],
+            divisions=[division1, division2],
+        )
 
-        teams2 = [Team(ownerId=owners[0].id, name="a2"), Team(ownerId=owners[1].id, name="b2")]
-        matchup2 = Matchup(teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2)
+        teams2 = [
+            Team(ownerId=owners[0].id, name="a2"),
+            Team(ownerId=owners[1].id, name="b2"),
+        ]
+        matchup2 = Matchup(
+            teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2
+        )
         week2 = Week(weekNumber=1, matchups=[matchup2])
         year2 = Year(yearNumber=2001, teams=teams2, weeks=[week2])
 
-        teams3 = [Team(ownerId=owners[0].id, name="a3"), Team(ownerId=owners[1].id, name="b3")]
-        matchup3 = Matchup(teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2)
+        teams3 = [
+            Team(ownerId=owners[0].id, name="a3"),
+            Team(ownerId=owners[1].id, name="b3"),
+        ]
+        matchup3 = Matchup(
+            teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2
+        )
         week3 = Week(weekNumber=1, matchups=[matchup3])
         year3 = Year(yearNumber=2002, teams=teams3, weeks=[week3])
 
@@ -60,6 +82,7 @@ class TestExcel(unittest.TestCase):
             worksheet2000TeamValues = [
                 [
                     "Team",
+                    "Division",
                     "Games Played",
                     "Wins",
                     "Losses",
@@ -93,6 +116,7 @@ class TestExcel(unittest.TestCase):
                 ],
                 [
                     "a",
+                    "d1",
                     1,
                     0,
                     1,
@@ -126,6 +150,7 @@ class TestExcel(unittest.TestCase):
                 ],
                 [
                     "b",
+                    "d2",
                     1,
                     1,
                     0,
@@ -411,22 +436,34 @@ class TestExcel(unittest.TestCase):
                 (workbook["2002 Matchups"], worksheet2002MatchupValues),
             ]
 
-            for i, (currentWorksheet, allWorksheetValues) in enumerate(yearWorksheetsAndValues):
+            for i, (currentWorksheet, allWorksheetValues) in enumerate(
+                yearWorksheetsAndValues
+            ):
                 for j, worksheetValues in enumerate(allWorksheetValues):
                     for k, worksheetValue in enumerate(worksheetValues):
                         row = j + 1
                         column = get_column_letter(k + 1)
-                        self.assertEqual(worksheetValue, currentWorksheet[f"{column}{row}"].value)
+                        self.assertEqual(
+                            worksheetValue, currentWorksheet[f"{column}{row}"].value
+                        )
                 # check that "next" cell is empty
                 self.assertIsNone(currentWorksheet["A4"].value)
                 # check legend
                 self.assertEqual("Filters Applied", currentWorksheet["A6"].value)
                 self.assertEqual("Week Number Start: 1", currentWorksheet["A7"].value)
                 self.assertEqual("Week Number End: 1", currentWorksheet["A8"].value)
-                self.assertEqual("Only Regular Season: False", currentWorksheet["A9"].value)
-                self.assertEqual("Only Post Season: False", currentWorksheet["A10"].value)
-                self.assertEqual("Only Championship: False", currentWorksheet["A11"].value)
-                self.assertEqual("Include Multi-Week Matchups: True", currentWorksheet["A12"].value)
+                self.assertEqual(
+                    "Only Regular Season: False", currentWorksheet["A9"].value
+                )
+                self.assertEqual(
+                    "Only Post Season: False", currentWorksheet["A10"].value
+                )
+                self.assertEqual(
+                    "Only Championship: False", currentWorksheet["A11"].value
+                )
+                self.assertEqual(
+                    "Include Multi-Week Matchups: True", currentWorksheet["A12"].value
+                )
                 self.assertIsNone(currentWorksheet["A13"].value)
 
             # test all time teams worksheet values
@@ -436,6 +473,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "Team",
                     "Owner",
+                    "Division",
                     "Year",
                     "Games Played",
                     "Wins",
@@ -471,6 +509,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "a",
                     "1",
+                    "d1",
                     2000,
                     1,
                     0,
@@ -506,6 +545,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "b",
                     "2",
+                    "d2",
                     2000,
                     1,
                     1,
@@ -541,6 +581,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "a2",
                     "1",
+                    "N/A",
                     2001,
                     1,
                     0,
@@ -576,6 +617,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "b2",
                     "2",
+                    "N/A",
                     2001,
                     1,
                     1,
@@ -611,6 +653,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "a3",
                     "1",
+                    "N/A",
                     2002,
                     1,
                     0,
@@ -646,6 +689,7 @@ class TestExcel(unittest.TestCase):
                 [
                     "b3",
                     "2",
+                    "N/A",
                     2002,
                     1,
                     1,
@@ -684,18 +728,30 @@ class TestExcel(unittest.TestCase):
                 values = allTimeTeamsValues[rowNumber - 1]
                 for columnNumber, value in enumerate(values):
                     cell = f"{get_column_letter(columnNumber + 1)}{rowNumber}"
-                    self.assertEqual(values[columnNumber], allTimeTeamsWorksheet[cell].value)
+                    self.assertEqual(
+                        values[columnNumber], allTimeTeamsWorksheet[cell].value
+                    )
             # check that "next" cell is empty
             self.assertIsNone(allTimeTeamsWorksheet["A8"].value)
             # check legend
             self.assertEqual("Filters Applied", allTimeTeamsWorksheet["A10"].value)
             self.assertEqual("Week Number Start: 1", allTimeTeamsWorksheet["A11"].value)
-            self.assertEqual("Year Number Start: 2000", allTimeTeamsWorksheet["A12"].value)
+            self.assertEqual(
+                "Year Number Start: 2000", allTimeTeamsWorksheet["A12"].value
+            )
             self.assertEqual("Week Number End: 1", allTimeTeamsWorksheet["A13"].value)
-            self.assertEqual("Year Number End: 2002", allTimeTeamsWorksheet["A14"].value)
-            self.assertEqual("Only Regular Season: False", allTimeTeamsWorksheet["A15"].value)
-            self.assertEqual("Only Post Season: False", allTimeTeamsWorksheet["A16"].value)
-            self.assertEqual("Only Championship: False", allTimeTeamsWorksheet["A17"].value)
+            self.assertEqual(
+                "Year Number End: 2002", allTimeTeamsWorksheet["A14"].value
+            )
+            self.assertEqual(
+                "Only Regular Season: False", allTimeTeamsWorksheet["A15"].value
+            )
+            self.assertEqual(
+                "Only Post Season: False", allTimeTeamsWorksheet["A16"].value
+            )
+            self.assertEqual(
+                "Only Championship: False", allTimeTeamsWorksheet["A17"].value
+            )
             self.assertIsNone(allTimeTeamsWorksheet["A18"].value)
 
             # test all time matchups worksheet values
@@ -725,18 +781,34 @@ class TestExcel(unittest.TestCase):
                 values = allTimeMatchupsValues[rowNumber - 1]
                 for columnNumber, value in enumerate(values):
                     cell = f"{get_column_letter(columnNumber + 1)}{rowNumber}"
-                    self.assertEqual(values[columnNumber], allTimeMatchupsWorksheet[cell].value)
+                    self.assertEqual(
+                        values[columnNumber], allTimeMatchupsWorksheet[cell].value
+                    )
             # check that "next" cell is empty
             self.assertIsNone(allTimeMatchupsWorksheet["A8"].value)
             # check legend
             self.assertEqual("Filters Applied", allTimeMatchupsWorksheet["A10"].value)
-            self.assertEqual("Week Number Start: 1", allTimeMatchupsWorksheet["A11"].value)
-            self.assertEqual("Year Number Start: 2000", allTimeMatchupsWorksheet["A12"].value)
-            self.assertEqual("Week Number End: 1", allTimeMatchupsWorksheet["A13"].value)
-            self.assertEqual("Year Number End: 2002", allTimeMatchupsWorksheet["A14"].value)
-            self.assertEqual("Only Regular Season: False", allTimeMatchupsWorksheet["A15"].value)
-            self.assertEqual("Only Post Season: False", allTimeMatchupsWorksheet["A16"].value)
-            self.assertEqual("Only Championship: False", allTimeMatchupsWorksheet["A17"].value)
+            self.assertEqual(
+                "Week Number Start: 1", allTimeMatchupsWorksheet["A11"].value
+            )
+            self.assertEqual(
+                "Year Number Start: 2000", allTimeMatchupsWorksheet["A12"].value
+            )
+            self.assertEqual(
+                "Week Number End: 1", allTimeMatchupsWorksheet["A13"].value
+            )
+            self.assertEqual(
+                "Year Number End: 2002", allTimeMatchupsWorksheet["A14"].value
+            )
+            self.assertEqual(
+                "Only Regular Season: False", allTimeMatchupsWorksheet["A15"].value
+            )
+            self.assertEqual(
+                "Only Post Season: False", allTimeMatchupsWorksheet["A16"].value
+            )
+            self.assertEqual(
+                "Only Championship: False", allTimeMatchupsWorksheet["A17"].value
+            )
             self.assertIsNone(allTimeMatchupsWorksheet["A18"].value)
 
             # test all time owners worksheet values
@@ -848,35 +920,59 @@ class TestExcel(unittest.TestCase):
                 values = allTimeOwnersValues[rowNumber - 1]
                 for columnNumber, value in enumerate(values):
                     cell = f"{get_column_letter(columnNumber + 1)}{rowNumber}"
-                    self.assertEqual(values[columnNumber], allTimeOwnersWorksheet[cell].value)
+                    self.assertEqual(
+                        values[columnNumber], allTimeOwnersWorksheet[cell].value
+                    )
             # check that "next" cell is empty
             self.assertIsNone(allTimeOwnersWorksheet["A4"].value)
             # check legend
             self.assertEqual("Filters Applied", allTimeOwnersWorksheet["A6"].value)
             self.assertEqual("Week Number Start: 1", allTimeOwnersWorksheet["A7"].value)
-            self.assertEqual("Year Number Start: 2000", allTimeOwnersWorksheet["A8"].value)
+            self.assertEqual(
+                "Year Number Start: 2000", allTimeOwnersWorksheet["A8"].value
+            )
             self.assertEqual("Week Number End: 1", allTimeOwnersWorksheet["A9"].value)
-            self.assertEqual("Year Number End: 2002", allTimeOwnersWorksheet["A10"].value)
-            self.assertEqual("Only Regular Season: False", allTimeOwnersWorksheet["A11"].value)
-            self.assertEqual("Only Post Season: False", allTimeOwnersWorksheet["A12"].value)
-            self.assertEqual("Only Championship: False", allTimeOwnersWorksheet["A13"].value)
+            self.assertEqual(
+                "Year Number End: 2002", allTimeOwnersWorksheet["A10"].value
+            )
+            self.assertEqual(
+                "Only Regular Season: False", allTimeOwnersWorksheet["A11"].value
+            )
+            self.assertEqual(
+                "Only Post Season: False", allTimeOwnersWorksheet["A12"].value
+            )
+            self.assertEqual(
+                "Only Championship: False", allTimeOwnersWorksheet["A13"].value
+            )
             self.assertIsNone(allTimeOwnersWorksheet["A14"].value)
 
     def test_leagueToExcel_filePathNotGiven_happyPath(self):
         owners, teams1 = getNDefaultOwnersAndTeams(2)
         teams1[0].name = "a"
         teams1[1].name = "b"
-        matchup1 = Matchup(teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2)
+        matchup1 = Matchup(
+            teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2
+        )
         week1 = Week(weekNumber=1, matchups=[matchup1])
         year1 = Year(yearNumber=2000, teams=teams1, weeks=[week1])
 
-        teams2 = [Team(ownerId=owners[0].id, name="a2"), Team(ownerId=owners[1].id, name="b2")]
-        matchup2 = Matchup(teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2)
+        teams2 = [
+            Team(ownerId=owners[0].id, name="a2"),
+            Team(ownerId=owners[1].id, name="b2"),
+        ]
+        matchup2 = Matchup(
+            teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2
+        )
         week2 = Week(weekNumber=1, matchups=[matchup2])
         year2 = Year(yearNumber=2001, teams=teams2, weeks=[week2])
 
-        teams3 = [Team(ownerId=owners[0].id, name="a3"), Team(ownerId=owners[1].id, name="b3")]
-        matchup3 = Matchup(teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2)
+        teams3 = [
+            Team(ownerId=owners[0].id, name="a3"),
+            Team(ownerId=owners[1].id, name="b3"),
+        ]
+        matchup3 = Matchup(
+            teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2
+        )
         week3 = Week(weekNumber=1, matchups=[matchup3])
         year3 = Year(yearNumber=2002, teams=teams3, weeks=[week3])
 
@@ -1257,7 +1353,9 @@ class TestExcel(unittest.TestCase):
                 (workbook["2002 Matchups"], worksheet2002MatchupValues),
             ]
 
-            for i, (currentWorksheet, allWorksheetValues) in enumerate(yearWorksheetsAndValues):
+            for i, (currentWorksheet, allWorksheetValues) in enumerate(
+                yearWorksheetsAndValues
+            ):
                 for j, worksheetValues in enumerate(allWorksheetValues):
                     for k, worksheetValue in enumerate(worksheetValues):
                         row = j + 1
@@ -1272,10 +1370,18 @@ class TestExcel(unittest.TestCase):
                 self.assertEqual("Filters Applied", currentWorksheet["A6"].value)
                 self.assertEqual("Week Number Start: 1", currentWorksheet["A7"].value)
                 self.assertEqual("Week Number End: 1", currentWorksheet["A8"].value)
-                self.assertEqual("Only Regular Season: False", currentWorksheet["A9"].value)
-                self.assertEqual("Only Post Season: False", currentWorksheet["A10"].value)
-                self.assertEqual("Only Championship: False", currentWorksheet["A11"].value)
-                self.assertEqual("Include Multi-Week Matchups: True", currentWorksheet["A12"].value)
+                self.assertEqual(
+                    "Only Regular Season: False", currentWorksheet["A9"].value
+                )
+                self.assertEqual(
+                    "Only Post Season: False", currentWorksheet["A10"].value
+                )
+                self.assertEqual(
+                    "Only Championship: False", currentWorksheet["A11"].value
+                )
+                self.assertEqual(
+                    "Include Multi-Week Matchups: True", currentWorksheet["A12"].value
+                )
                 self.assertIsNone(currentWorksheet["A13"].value)
 
             # test all time teams worksheet values
@@ -1542,12 +1648,22 @@ class TestExcel(unittest.TestCase):
             # check legend
             self.assertEqual("Filters Applied", allTimeTeamsWorksheet["A10"].value)
             self.assertEqual("Week Number Start: 1", allTimeTeamsWorksheet["A11"].value)
-            self.assertEqual("Year Number Start: 2000", allTimeTeamsWorksheet["A12"].value)
+            self.assertEqual(
+                "Year Number Start: 2000", allTimeTeamsWorksheet["A12"].value
+            )
             self.assertEqual("Week Number End: 1", allTimeTeamsWorksheet["A13"].value)
-            self.assertEqual("Year Number End: 2002", allTimeTeamsWorksheet["A14"].value)
-            self.assertEqual("Only Regular Season: False", allTimeTeamsWorksheet["A15"].value)
-            self.assertEqual("Only Post Season: False", allTimeTeamsWorksheet["A16"].value)
-            self.assertEqual("Only Championship: False", allTimeTeamsWorksheet["A17"].value)
+            self.assertEqual(
+                "Year Number End: 2002", allTimeTeamsWorksheet["A14"].value
+            )
+            self.assertEqual(
+                "Only Regular Season: False", allTimeTeamsWorksheet["A15"].value
+            )
+            self.assertEqual(
+                "Only Post Season: False", allTimeTeamsWorksheet["A16"].value
+            )
+            self.assertEqual(
+                "Only Championship: False", allTimeTeamsWorksheet["A17"].value
+            )
             self.assertIsNone(allTimeTeamsWorksheet["A18"].value)
 
             # test all time matchups worksheet values
@@ -1585,13 +1701,27 @@ class TestExcel(unittest.TestCase):
             self.assertIsNone(allTimeMatchupsWorksheet["A8"].value)
             # check legend
             self.assertEqual("Filters Applied", allTimeMatchupsWorksheet["A10"].value)
-            self.assertEqual("Week Number Start: 1", allTimeMatchupsWorksheet["A11"].value)
-            self.assertEqual("Year Number Start: 2000", allTimeMatchupsWorksheet["A12"].value)
-            self.assertEqual("Week Number End: 1", allTimeMatchupsWorksheet["A13"].value)
-            self.assertEqual("Year Number End: 2002", allTimeMatchupsWorksheet["A14"].value)
-            self.assertEqual("Only Regular Season: False", allTimeMatchupsWorksheet["A15"].value)
-            self.assertEqual("Only Post Season: False", allTimeMatchupsWorksheet["A16"].value)
-            self.assertEqual("Only Championship: False", allTimeMatchupsWorksheet["A17"].value)
+            self.assertEqual(
+                "Week Number Start: 1", allTimeMatchupsWorksheet["A11"].value
+            )
+            self.assertEqual(
+                "Year Number Start: 2000", allTimeMatchupsWorksheet["A12"].value
+            )
+            self.assertEqual(
+                "Week Number End: 1", allTimeMatchupsWorksheet["A13"].value
+            )
+            self.assertEqual(
+                "Year Number End: 2002", allTimeMatchupsWorksheet["A14"].value
+            )
+            self.assertEqual(
+                "Only Regular Season: False", allTimeMatchupsWorksheet["A15"].value
+            )
+            self.assertEqual(
+                "Only Post Season: False", allTimeMatchupsWorksheet["A16"].value
+            )
+            self.assertEqual(
+                "Only Championship: False", allTimeMatchupsWorksheet["A17"].value
+            )
             self.assertIsNone(allTimeMatchupsWorksheet["A18"].value)
 
             # test all time owners worksheet values
@@ -1712,29 +1842,51 @@ class TestExcel(unittest.TestCase):
             # check legend
             self.assertEqual("Filters Applied", allTimeOwnersWorksheet["A6"].value)
             self.assertEqual("Week Number Start: 1", allTimeOwnersWorksheet["A7"].value)
-            self.assertEqual("Year Number Start: 2000", allTimeOwnersWorksheet["A8"].value)
+            self.assertEqual(
+                "Year Number Start: 2000", allTimeOwnersWorksheet["A8"].value
+            )
             self.assertEqual("Week Number End: 1", allTimeOwnersWorksheet["A9"].value)
-            self.assertEqual("Year Number End: 2002", allTimeOwnersWorksheet["A10"].value)
-            self.assertEqual("Only Regular Season: False", allTimeOwnersWorksheet["A11"].value)
-            self.assertEqual("Only Post Season: False", allTimeOwnersWorksheet["A12"].value)
-            self.assertEqual("Only Championship: False", allTimeOwnersWorksheet["A13"].value)
+            self.assertEqual(
+                "Year Number End: 2002", allTimeOwnersWorksheet["A10"].value
+            )
+            self.assertEqual(
+                "Only Regular Season: False", allTimeOwnersWorksheet["A11"].value
+            )
+            self.assertEqual(
+                "Only Post Season: False", allTimeOwnersWorksheet["A12"].value
+            )
+            self.assertEqual(
+                "Only Championship: False", allTimeOwnersWorksheet["A13"].value
+            )
             self.assertIsNone(allTimeOwnersWorksheet["A14"].value)
 
     def test_leagueToExcel_returnedWorkbookIsSameAsLoadedWorkbook(self):
         owners, teams1 = getNDefaultOwnersAndTeams(2)
         teams1[0].name = "a"
         teams1[1].name = "b"
-        matchup1 = Matchup(teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2)
+        matchup1 = Matchup(
+            teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2
+        )
         week1 = Week(weekNumber=1, matchups=[matchup1])
         year1 = Year(yearNumber=2000, teams=teams1, weeks=[week1])
 
-        teams2 = [Team(ownerId=owners[0].id, name="a2"), Team(ownerId=owners[1].id, name="b2")]
-        matchup2 = Matchup(teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2)
+        teams2 = [
+            Team(ownerId=owners[0].id, name="a2"),
+            Team(ownerId=owners[1].id, name="b2"),
+        ]
+        matchup2 = Matchup(
+            teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2
+        )
         week2 = Week(weekNumber=1, matchups=[matchup2])
         year2 = Year(yearNumber=2001, teams=teams2, weeks=[week2])
 
-        teams3 = [Team(ownerId=owners[0].id, name="a3"), Team(ownerId=owners[1].id, name="b3")]
-        matchup3 = Matchup(teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2)
+        teams3 = [
+            Team(ownerId=owners[0].id, name="a3"),
+            Team(ownerId=owners[1].id, name="b3"),
+        ]
+        matchup3 = Matchup(
+            teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2
+        )
         week3 = Week(weekNumber=1, matchups=[matchup3])
         year3 = Year(yearNumber=2002, teams=teams3, weeks=[week3])
 
@@ -1747,7 +1899,9 @@ class TestExcel(unittest.TestCase):
             # open created Excel file to check that it was saved correctly
             loadedWorkbook = load_workbook(filename=fullPath)
 
-            self.assertEqual(len(returnedWorkbook.worksheets), len(loadedWorkbook.worksheets))
+            self.assertEqual(
+                len(returnedWorkbook.worksheets), len(loadedWorkbook.worksheets)
+            )
             for ws1, ws2 in zip(returnedWorkbook.worksheets, loadedWorkbook.worksheets):
                 # Compare worksheet names and contents
                 self.assertEqual(ws1.title, ws2.title)
@@ -1763,7 +1917,6 @@ class TestExcel(unittest.TestCase):
                         self.assertAlmostEqual(cell1Value, cell2Value)
 
     def test_leagueToExcel_leagueIsNone_raisesException(self):
-
         with self.assertRaises(ValueError) as context:
             leagueToExcel(None, "")
         self.assertEqual("'league' has not been set.", str(context.exception))
@@ -1772,17 +1925,29 @@ class TestExcel(unittest.TestCase):
         owners, teams1 = getNDefaultOwnersAndTeams(2)
         teams1[0].name = "a"
         teams1[1].name = "b"
-        matchup1 = Matchup(teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2)
+        matchup1 = Matchup(
+            teamAId=teams1[0].id, teamBId=teams1[1].id, teamAScore=1, teamBScore=2
+        )
         week1 = Week(weekNumber=1, matchups=[matchup1])
         year1 = Year(yearNumber=2000, teams=teams1, weeks=[week1])
 
-        teams2 = [Team(ownerId=owners[0].id, name="a2"), Team(ownerId=owners[1].id, name="b2")]
-        matchup2 = Matchup(teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2)
+        teams2 = [
+            Team(ownerId=owners[0].id, name="a2"),
+            Team(ownerId=owners[1].id, name="b2"),
+        ]
+        matchup2 = Matchup(
+            teamAId=teams2[0].id, teamBId=teams2[1].id, teamAScore=1, teamBScore=2
+        )
         week2 = Week(weekNumber=1, matchups=[matchup2])
         year2 = Year(yearNumber=2001, teams=teams2, weeks=[week2])
 
-        teams3 = [Team(ownerId=owners[0].id, name="a3"), Team(ownerId=owners[1].id, name="b3")]
-        matchup3 = Matchup(teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2)
+        teams3 = [
+            Team(ownerId=owners[0].id, name="a3"),
+            Team(ownerId=owners[1].id, name="b3"),
+        ]
+        matchup3 = Matchup(
+            teamAId=teams3[0].id, teamBId=teams3[1].id, teamAScore=1, teamBScore=2
+        )
         week3 = Week(weekNumber=1, matchups=[matchup3])
         year3 = Year(yearNumber=1999, teams=teams3, weeks=[week3])
 
