@@ -11,12 +11,14 @@ from test.helper.prototypes import getNDefaultOwnersAndTeams
 
 
 class TestStatSheet(unittest.TestCase):
-
     def test_leagueStatSheet(self):
         from leeger.util.stat_sheet import leagueStatSheet
+
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        matchup = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2
+        )
         week = Week(weekNumber=1, matchups=[matchup])
         year = Year(yearNumber=2000, teams=teams, weeks=[week])
 
@@ -69,12 +71,17 @@ class TestStatSheet(unittest.TestCase):
 
     def test_leagueStatSheet_leagueMedianGamesIsTrueInAnyYearSettings(self):
         from leeger.util.stat_sheet import leagueStatSheet
+
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        matchup = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2
+        )
         week = Week(weekNumber=1, matchups=[matchup])
         yearSettings = YearSettings(leagueMedianGames=True)
-        year = Year(yearNumber=2000, teams=teams, weeks=[week], yearSettings=yearSettings)
+        year = Year(
+            yearNumber=2000, teams=teams, weeks=[week], yearSettings=yearSettings
+        )
 
         league = League(name="TEST", owners=owners, years=[year])
 
@@ -85,9 +92,12 @@ class TestStatSheet(unittest.TestCase):
 
     def test_yearStatSheet(self):
         from leeger.util.stat_sheet import yearStatSheet
+
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        matchup = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2
+        )
         week = Week(weekNumber=1, matchups=[matchup])
         year = Year(yearNumber=2000, teams=teams, weeks=[week])
 
@@ -143,21 +153,18 @@ class TestStatSheet(unittest.TestCase):
 
     def test_yearStatSheet_ownerNamesAndYearsGiven(self):
         from leeger.util.stat_sheet import yearStatSheet
+
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        matchup = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2
+        )
         week = Week(weekNumber=1, matchups=[matchup])
         year = Year(yearNumber=2000, teams=teams, weeks=[week])
 
-        ownerNames = {
-            teams[0].id: "owner0",
-            teams[1].id: "owner1"
-        }
+        ownerNames = {teams[0].id: "owner0", teams[1].id: "owner1"}
 
-        years = {
-            teams[0].id: 2000,
-            teams[1].id: 2000
-        }
+        years = {teams[0].id: 2000, teams[1].id: 2000}
 
         yearStatSheet = yearStatSheet(year, ownerNames=ownerNames, years=years)
 
@@ -211,12 +218,17 @@ class TestStatSheet(unittest.TestCase):
 
     def test_yearStatSheet_leagueMedianGamesIsTrue(self):
         from leeger.util.stat_sheet import yearStatSheet
+
         owners, teams = getNDefaultOwnersAndTeams(2)
 
-        matchup = Matchup(teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2)
+        matchup = Matchup(
+            teamAId=teams[0].id, teamBId=teams[1].id, teamAScore=1, teamBScore=2
+        )
         week = Week(weekNumber=1, matchups=[matchup])
         yearSettings = YearSettings(leagueMedianGames=True)
-        year = Year(yearNumber=2000, teams=teams, weeks=[week], yearSettings=yearSettings)
+        year = Year(
+            yearNumber=2000, teams=teams, weeks=[week], yearSettings=yearSettings
+        )
 
         yearStatSheet = yearStatSheet(year)
 
